# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkShapeLabelMapFilterPython
else:
    import _itkShapeLabelMapFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkStatisticsLabelObjectPython
import itk.itkHistogramPython
import itk.itkSamplePython
import itk.itkArrayPython
import itk.itkIndexPython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkOptimizerParametersPython
import itk.itkArray2DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVariableLengthVectorPython
import itk.itkDiffusionTensor3DPython
import itk.itkTransformBasePython
import itk.itkShapeLabelObjectPython
import itk.itkLabelObjectPython
import itk.itkLabelObjectLinePython
import itk.itkImageRegionPython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkInPlaceLabelMapFilterPython
import itk.itkLabelMapFilterPython
import itk.ITKLabelMapBasePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkVectorImagePython

def itkShapeLabelMapFilterLM2IUL2_New():
    return itkShapeLabelMapFilterLM2IUL2.New()

class itkShapeLabelMapFilterLM2IUL2(itk.itkInPlaceLabelMapFilterPython.itkInPlaceLabelMapFilterLM2):
    r"""Proxy of C++ itkShapeLabelMapFilterLM2IUL2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShapeLabelMapFilterLM2IUL2_Pointer"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShapeLabelMapFilterLM2IUL2_Pointer"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_Clone(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_ComputePerimeterOff(self)

    def SetComputeOrientedBoundingBox(self, _arg):
        r"""
        SetComputeOrientedBoundingBox(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_SetComputeOrientedBoundingBox(self, _arg)

    def GetComputeOrientedBoundingBox(self):
        r"""GetComputeOrientedBoundingBox(self) -> bool const &"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_GetComputeOrientedBoundingBox(self)

    def ComputeOrientedBoundingBoxOn(self):
        r"""ComputeOrientedBoundingBoxOn(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_ComputeOrientedBoundingBoxOn(self)

    def ComputeOrientedBoundingBoxOff(self):
        r"""ComputeOrientedBoundingBoxOff(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_ComputeOrientedBoundingBoxOff(self)

    def SetLabelImage(self, input):
        r"""
        SetLabelImage(self, input)

        Parameters
        ----------
        input: itkImageUL2 const *

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_SetLabelImage(self, input)
    __swig_destroy__ = _itkShapeLabelMapFilterPython.delete_itkShapeLabelMapFilterLM2IUL2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapeLabelMapFilterLM2IUL2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShapeLabelMapFilterLM2IUL2

        Create a new object of the class itkShapeLabelMapFilterLM2IUL2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShapeLabelMapFilterLM2IUL2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShapeLabelMapFilterLM2IUL2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShapeLabelMapFilterLM2IUL2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShapeLabelMapFilterLM2IUL2 in _itkShapeLabelMapFilterPython:
_itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM2IUL2_swigregister(itkShapeLabelMapFilterLM2IUL2)

def itkShapeLabelMapFilterLM3IUL3_New():
    return itkShapeLabelMapFilterLM3IUL3.New()

class itkShapeLabelMapFilterLM3IUL3(itk.itkInPlaceLabelMapFilterPython.itkInPlaceLabelMapFilterLM3):
    r"""Proxy of C++ itkShapeLabelMapFilterLM3IUL3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShapeLabelMapFilterLM3IUL3_Pointer"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShapeLabelMapFilterLM3IUL3_Pointer"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_Clone(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_ComputePerimeterOff(self)

    def SetComputeOrientedBoundingBox(self, _arg):
        r"""
        SetComputeOrientedBoundingBox(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_SetComputeOrientedBoundingBox(self, _arg)

    def GetComputeOrientedBoundingBox(self):
        r"""GetComputeOrientedBoundingBox(self) -> bool const &"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_GetComputeOrientedBoundingBox(self)

    def ComputeOrientedBoundingBoxOn(self):
        r"""ComputeOrientedBoundingBoxOn(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_ComputeOrientedBoundingBoxOn(self)

    def ComputeOrientedBoundingBoxOff(self):
        r"""ComputeOrientedBoundingBoxOff(self)"""
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_ComputeOrientedBoundingBoxOff(self)

    def SetLabelImage(self, input):
        r"""
        SetLabelImage(self, input)

        Parameters
        ----------
        input: itkImageUL3 const *

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_SetLabelImage(self, input)
    __swig_destroy__ = _itkShapeLabelMapFilterPython.delete_itkShapeLabelMapFilterLM3IUL3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapeLabelMapFilterLM3IUL3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShapeLabelMapFilterLM3IUL3

        Create a new object of the class itkShapeLabelMapFilterLM3IUL3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShapeLabelMapFilterLM3IUL3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShapeLabelMapFilterLM3IUL3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShapeLabelMapFilterLM3IUL3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShapeLabelMapFilterLM3IUL3 in _itkShapeLabelMapFilterPython:
_itkShapeLabelMapFilterPython.itkShapeLabelMapFilterLM3IUL3_swigregister(itkShapeLabelMapFilterLM3IUL3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def shape_label_map_filter(*args: itkt.ImageLike,  compute_feret_diameter: bool=..., compute_perimeter: bool=..., compute_oriented_bounding_box: bool=..., label_image: itkt.Image=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ShapeLabelMapFilter"""
    import itk

    kwarg_typehints = { 'compute_feret_diameter':compute_feret_diameter,'compute_perimeter':compute_perimeter,'compute_oriented_bounding_box':compute_oriented_bounding_box,'label_image':label_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ShapeLabelMapFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def shape_label_map_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLabelMap.ShapeLabelMapFilter
    shape_label_map_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    shape_label_map_filter.__doc__ = filter_object.__doc__



